<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>EditHatch</name>
    <message>
        <location filename="../EditHatch.js" line="+61"/>
        <source>Choose hatch</source>
        <translation>ハッチングを選択</translation>
    </message>
    <message>
        <location filename="../EditHatchInit.js" line="+2"/>
        <source>Edit &amp;Hatch</source>
        <translation>ハッチングを編集</translation>
    </message>
</context>
<context>
    <name>EditText</name>
    <message>
        <source>Choose text</source>
        <translation type="vanished">テキストを選択</translation>
    </message>
    <message>
        <source>Edit Te&amp;xt</source>
        <translation type="vanished">&amp;x テキスト編集</translation>
    </message>
    <message>
        <source>Edit text</source>
        <translation type="vanished">テキスト編集</translation>
    </message>
</context>
</TS>
